List all datasets that have stored tokens in environment variables
bdpe_list_tokens.RdThis function returns a character vector of dataset names
that have their tokens stored in environment variables.
Specifically, it looks for variables that begin with the prefix
"BigDataPE_".