Remove the token associated with a specific dataset
bdpe_remove_token.RdThis function removes the authentication token stored in an environment variable for a specific dataset. If the token is not found, it prints a message and does not throw an error.